@@ -1,12 +1,12 @@
 #!/usr/bin/perl
 
 package Catalyst::Plugin::Cache;
-use base qw/Class::Data::Inheritable Class::Accessor::Fast/;
+use base qw(Class::Accessor::Fast Class::Data::Inheritable);
 
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.05";
 
 use Scalar::Util ();
 use Catalyst::Utils ();
@@ -81,7 +81,11 @@ sub setup_generic_cache_backend {
     my %config = %$config;
 
     if ( my $class = delete $config{class} ) {
-        $app->setup_cache_backend_by_class( $name, $class, \%config );
+        eval { $app->setup_cache_backend_by_class( $name, $class, %config ) }
+            ||
+        eval { $app->setup_cache_backend_by_class( $name, $class, \%config ) }
+            ||
+        die "Couldn't construct $class with either list style or hash ref style param passing: $@";
     } elsif ( my $store = delete $config->{store} || $app->default_cache_store ) {
         my $method = lc("setup_${store}_cache_backend");
 
@@ -489,7 +493,7 @@ Instantiate a backend from a L<Cache> compatible class. E.g.
     };
     
     $c->config->{cache}{backends}{large_things} = {
-        class => "Cache::Memcached::Managed",
+        class => "Cache::Memcached",
         data  => '1.2.3.4:1234',
     };
 
